package com.tzld.piaoquan.ad.engine.service.score;


import com.tzld.piaoquan.ad.engine.commons.score.BaseLRModelScorer;
import com.tzld.piaoquan.ad.engine.commons.score.ScoreParam;
import com.tzld.piaoquan.ad.engine.commons.score.ScorerConfigInfo;
import com.tzld.piaoquan.ad.engine.commons.score.model.LRModel;
import com.tzld.piaoquan.recommend.feature.domain.ad.base.AdRankItem;
import com.tzld.piaoquan.recommend.feature.domain.ad.base.UserAdFeature;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.Collections;
import java.util.List;


//@Service
public class VlogMergeEcpmScorer extends BaseLRModelScorer {

    private final static Logger LOGGER = LoggerFactory.getLogger(VlogMergeEcpmScorer.class);


    public VlogMergeEcpmScorer(ScorerConfigInfo configInfo) {
        super(configInfo);
    }


    @Override
    public List<AdRankItem> scoring(final ScoreParam param,
                                    final UserAdFeature userFeature,
                                    final List<AdRankItem> rankItems) {


        long startTime = System.currentTimeMillis();
        List<AdRankItem> result = mergetEcpm(rankItems);
        LOGGER.debug("ctr ranker time java items size={}, time={} ", result != null ? result.size() : 0,
                System.currentTimeMillis() - startTime);

        return result;
    }


    public List<AdRankItem> mergetEcpm(List<AdRankItem> items) {
        long startTime = System.currentTimeMillis();

        for (AdRankItem item : items) {
            try {
                double cpa = item.getCpa();
                double bid1 = item.getBid1();
                double bid2 = item.getBid2();
                double pctr = item.getCtr();
                double pcvr = item.getCvr();
                //todo
                double ecpm = cpa * bid1 * bid2 * pcvr * pctr * 1000d;
//                double ecpm = cpa * bid1 * bid2 * pcvr * pctr;
                item.setEcpm1(ecpm/1000d);
                item.setScore(ecpm/1000d);
            } catch (Exception e) {
                LOGGER.error("merge Ecpm Score: {} error", "");
                item.setCtr(0.0);
            }
            LOGGER.debug("merge Ecpm ranker , score: {}->{}", "");
        }
        Collections.sort(items);
        return items;
    }

}